// $Id: HarmonicsPath.cc 2098 2007-02-25 22:51:38Z flaterco $

/*  HarmonicsPath  Vector of harmonics file names as specified by environment.

    Copyright (C) 1997  David Flater.

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
*/

#include "common.hh"
#include "HarmonicsPath.hh"


HarmonicsPath::HarmonicsPath ():
  _noPathProvided(false) {

  // Get HFILE_PATH from environment or /etc/xtide.conf
  Dstr hfile_path (getenv ("HFILE_PATH"));
  if (hfile_path.isNull()) {
    FILE *configfile;
    if ((configfile = fopen ("/etc/xtide.conf", "r"))) {
      hfile_path.getline (configfile);
      fclose (configfile);
    }
  }
  _origPath = hfile_path;
  if (hfile_path.isNull()) {
    _noPathProvided = true;
    hfile_path = "harmonics.tcd";
  }

  // Trying to tolerate whitespace in file names.
  while (hfile_path.length()) {
    int i = hfile_path.strchr (':');
    if (i == 0)
      hfile_path /= 1;
    else if (i < 0) {
      push_back (hfile_path);
      return;
    } else {
      Dstr temp (hfile_path);
      temp -= i;
      push_back (temp);
      hfile_path /= i+1;
    }
  }
}


const bool HarmonicsPath::noPathProvided() {
  return _noPathProvided;
}


constString HarmonicsPath::origPath() {
  return _origPath.aschar();
}

// Cleanup2006 Done
